@@ -24,20 +24,33 @@ class AnnotationNode(Node):
             return await self.handle_user_input(organization, project, user_input)
 
     async def handle_user_input(self, organization, project, user_input) -> str:
-        raise Exception('Test Drone build')
-        ic(user_input)
-
         input = UserInput.parse_obj(user_input)
+
+        if input.data.event_type == EventType.ESC_Pressed:
+            self.reset_history(input.frontend_id)
+            return ''
+
         await self.download_image(input.data.context, input.data.image_uuid)
         history = self.get_history(input.frontend_id)
-        tool_result = await self.tool.handle_user_input(input, history)
-        ic(tool_result)
+        try:
+            tool_result = await self.tool.handle_user_input(input, history)
+        except:
+            self.reset_history(input.frontend_id)
+            raise
+
         if tool_result.annotation:
             result = await self.sio_client.call('update_segmentation_annotation', (organization,
                                                                                    project, jsonable_encoder(tool_result.annotation)), timeout=2)
 
         return tool_result.svg
 
+    def reset_history(self,frontend_id: str) -> None:
+        try:
+            del self.histories[frontend_id]
+        except:
+            pass
+        
+
     def get_history(self, frontend_id: str) -> dict:
         if not frontend_id in self.histories.keys():
             self.histories[frontend_id] = self.tool.create_empty_history()
